"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = __importDefault(require("chalk"));
const ci_info_1 = require("ci-info");
const which_pm_runs_1 = __importDefault(require("which-pm-runs"));
const checkGitDirEnv_1 = require("../checkGitDirEnv");
const debug_1 = require("../debug");
const _1 = require("./");
const gitRevParse_1 = require("./gitRevParse");
// Skip install if HUSKY_SKIP_INSTALL is true
function checkSkipInstallEnv() {
    if (['1', 'true'].includes(process.env.HUSKY_SKIP_INSTALL || '')) {
        console.log('HUSKY_SKIP_INSTALL is set to true,', 'skipping Git hooks installation.');
        process.exit(0);
    }
}
function getGitMeta() {
    const { prefix, gitCommonDir } = gitRevParse_1.gitRevParse();
    debug_1.debug('Git rev-parse command returned:');
    debug_1.debug(`  --git-common-dir: ${gitCommonDir}`);
    debug_1.debug(`  --show-prefix: ${prefix}`);
    return { prefix, gitCommonDir };
}
// Get INIT_CWD env variable
function getInitCwdEnv() {
    const { INIT_CWD } = process.env;
    if (INIT_CWD === undefined) {
        const { name, version } = which_pm_runs_1.default();
        throw new Error(`INIT_CWD is not set, please upgrade your package manager (${name} ${version})`);
    }
    debug_1.debug(`INIT_CWD is set to ${INIT_CWD}`);
    return INIT_CWD;
}
function run() {
    debug_1.debug(`Current working directory is ${process.cwd()}`);
    debug_1.debug(`INIT_CWD environment variable is set to ${process.env.INIT_CWD}`);
    const action = process.argv[2];
    try {
        console.log('husky > %s git hooks', action === 'install' ? 'Setting up' : 'Uninstalling');
        if (action === 'install')
            checkSkipInstallEnv();
        checkGitDirEnv_1.checkGitDirEnv();
        const { gitCommonDir, prefix } = getGitMeta();
        const INIT_CWD = getInitCwdEnv();
        if (action === 'install') {
            const { name: pmName } = which_pm_runs_1.default();
            debug_1.debug(`Package manager: ${pmName}`);
            _1.install({ gitCommonDir, prefix, pmName, isCI: ci_info_1.isCI, INIT_CWD });
        }
        else {
            _1.uninstall({ gitCommonDir, INIT_CWD });
        }
        console.log(`husky > Done`);
    }
    catch (error) {
        console.log(chalk_1.default.red(error.message.trim()));
        console.log(chalk_1.default.red(`husky > Failed to ${action}`));
    }
}
run();
